@@ -2,9 +2,9 @@
 #' Generate kernel function
 #'
 #' @description
-#' Generates kernel function
+#' Generates a kernel function
 #'
-#' @param t standardized vector (z-score)
+#' @param t A standardized vector (z-score)
 #'
 #' @return
 #' probability distribution
@@ -12,7 +12,7 @@
 #' @keywords internal
 #'
 #'
-generate_kernel <- function(t){
+generate_kernel <- function(t) {
   stats::dnorm(t)
 }
 
@@ -28,14 +28,14 @@ generate_kernel <- function(t){
 #' return value (TODO)
 #' @keywords internal
 #'
-w_fun <- function(bw,matched_w,w_vals){
+w_fun <- function(bw, matched_w, w_vals){
     w_avals <- NULL
-    for (w_val in w_vals){
-      w_std <- (matched_w-w_val)/bw
-      kern_std <- generate_kernel(w_std)/bw
-      tmp_mean <- mean(w_std^2*kern_std)
-      w_avals <- c(w_avals, tmp_mean*(generate_kernel(0)/bw) /
-                   (mean(kern_std)*tmp_mean-mean(w_std*kern_std)^2))
+    for (w_val in w_vals) {
+      w_std <- (matched_w - w_val) / bw
+      kern_std <- generate_kernel(w_std) / bw
+      tmp_mean <- mean(w_std ^ 2 * kern_std)
+      w_avals <- c(w_avals, tmp_mean * (generate_kernel(0) / bw) /
+                   (mean(kern_std) * tmp_mean - mean(w_std * kern_std) ^ 2))
   }
-  return(w_avals/length(matched_w))
-}
\ No newline at end of file
+  return(w_avals / length(matched_w))
+}
