@@ -13,6 +13,9 @@
 #' Returns fitted values, or the prediction made by the model for each observation.
 #' @keywords internal
 #'
-estimate_hat_vals <- function(bw,matched_w,w_vals){
-  stats::approx(w_vals,w_fun(bw,matched_w,w_vals),xout=matched_w,rule=2)$y
+estimate_hat_vals <- function(bw, matched_w, w_vals) {
+  stats::approx(w_vals,
+                w_fun(bw, matched_w, w_vals),
+                xout = matched_w,
+                rule=2)$y
 }
